History
=======

3.0.0 (2016-01-24)
++++++++++++++++++

- Support Python 3.5
- Refactoring
- Rename ``text_spacing()`` to ``spacing_text()``

2.5.6.3 (2015-05-18)
++++++++++++++++++++

- Add an alias to ``spacing()``: ``text_spacing()``
- Fix unicode issue in Python 2.x

2.5.6.2 (2015-05-17)
++++++++++++++++++++

- Fix setup.py

2.5.6 (2015-05-17)
++++++++++++++++++

- Synchronize version number with `paranoid-auto-spacing <https://github.com/vinta/paranoid-auto-spacing>`_
- Improve Paranoid Text Spacing algorithm

1.0.0 (2014-02-12)
++++++++++++++++++

- Hello World
